#ifndef JTAG_H
#define JTAG_H

/*--------------------------------------------------------------------

       SCHEMATIC FOR THE PARALLEL PORT INTERFACE CIRCUIT

   NOTE: Power comes from the JTAG connector (3.3 V) and feeds
         just the 74HC240 and the pullups. The 74HC240 works OK
         at 3.3 Volts. Instead of a 74HC240, a pair of 74HC14's
         can also be used. Put also some decoupling on VDD
         (10 uF will do).


   JTAG VDD -------------------------------  +3.3V
   (PIN 1+2)          |                        |
                 74HC240 VDD                   |
                                              [5K]
                                               |
   JTAG TMS  ________/|______/|_________[22K]__|___  D0 (LPT1)
    (PIN 7)          \|      \|                       (PIN 2)
                 74HC240    74HC240

                                             +3.3V
                                               |
                                              [5K]
   JTAG TCK  ________/|______/|_________[22K]__|___  D1 (LPT1)
    (PIN 9)          \|      \|                       (PIN 3)
                 74HC240    74HC240

                                             +3.3V
                                               |
                                              [5K]
   JTAG TDI  ________/|______/|_________[22K]__|___  D2 (LPT1)
    (PIN 5)          \|      \|                       (PIN 4)
                 74HC240    74HC240



   JTAG TDO  ________|\______|\__________________  SELECT (LPT1)
    (PIN 13)         |/      |/                       (PIN 13)
                 74HC240    74HC240



   JTAG GND  -------------------------------------- GND  (LPT1)
    (PIN 20)          |     |      |               (PINS 18..25)
                74HC240 E1  |  74HC240 E2
                            |
                        74HC240 GND

---------------------------------------------------------------*/

#ifdef USE_MAIN
#include <sys/io.h>
#else
#include <asm/io.h>
#include <linux/delay.h>
#endif

/* Parallel port i/o addr. (LPT1) */
extern int DATA_PORT; 	//    0x378
extern int STATUS_PORT;	//  DATA_PORT+1

#include "opcodes.h"

/***-------------------------------------***/
/*** Masks for the parallel port pins    ***/
/***-------------------------------------***/

/* Change these masks if you change the connections */

/* TMS, TCK & TDI are connected to one pin each of D0-D7 (data port) */
/* TDO is connected to one pin of the status port (SELECT) */

/*
#define MASK_RST_BIT   8	//only used by wiggler
#define MASK_TMS_BIT   1
#define MASK_TCK_BIT   2
#define MASK_TDI_BIT   4
#define MASK_TDO_BIT   0x10

// Polarity of signals
#define INVERT_RST 0
#define INVERT_TMS 0
#define INVERT_TCK 0
#define INVERT_TDI 0

#define INVERT_TDO 0
*/

/* Wiggler: NRST=D0	TMS=D1	TCK=D2	TDI=D3	NTRST=D4	TDO=Busy	*/
#define MASK_RST_BIT   8	//only used by wiggler
#define MASK_TMS_BIT   1
#define MASK_TCK_BIT   2
#define MASK_TDI_BIT   4
#define MASK_TDO_BIT   0x10

// Polarity of signals
#define INVERT_RST 0
#define INVERT_TMS 0
#define INVERT_TCK 0
#define INVERT_TDI 0

#define INVERT_TDO 0

#ifdef USE_MAIN
extern int verbose;
#endif

void initialize_jtag_hardware(void);
void cpu_reset(int rst);
int jam_jtag_io(int tms, int tdi, int read_tdo);
void close_jtag_hardware(void);
#ifdef USE_MAIN
    void usleep(int microseconds);
#else
#	define usleep(a) udelay(a)
#endif

#endif
